OC.L10N.register(
    "lib",
    {
    "Cannot write into \"config\" directory!" : "Não é possível gravar no diretório \"config\"!",
    "This can usually be fixed by giving the web server write access to the config directory." : "Isso geralmente pode ser corrigido dando ao servidor web acesso de gravação ao diretório de configuração.",
    "But, if you prefer to keep config.php file read only, set the option \"config_is_read_only\" to true in it." : "Mas, se você preferir manter o arquivo config.php somente para leitura, defina a opção \"config_is_read_only\" como true nele. ",
    "See %s" : "Ver %s",
    "The files of the app %1$s were not replaced correctly. Make sure it is a version compatible with the server." : "Os arquivos do aplicativo %1$s não foram instalados corretamente. Certifique-se que é uma versão compatível com seu servidor.",
    "Sample configuration detected" : "Configuração de exemplo detectada",
    "It has been detected that the sample configuration has been copied. This can break your installation and is unsupported. Please read the documentation before performing changes on config.php" : "Foi detectado que a configuração de exemplo foi copiada. Isso pode terminar sua instalação e não é suportado. Por favor leia a documentação antes de realizar mudanças no config.php",
    "404" : "404",
    "The page could not be found on the server." : "A página não pôde ser encontrada no servidor.",
    "%s email verification" : "%s e-mail de verificação",
    "Email verification" : "E-mail de verificação",
    "Click the following button to confirm your email." : "Clique no botão a seguir para confirmar seu e-mail.",
    "Click the following link to confirm your email." : "Clique no link a seguir para confirmar seu e-mail.",
    "Confirm your email" : "Confirme seu e-mail",
    "Other activities" : "Outras atividades",
    "%1$s and %2$s" : "%1$s e %2$s",
    "%1$s, %2$s and %3$s" : "%1$s, %2$s e %3$s",
    "%1$s, %2$s, %3$s and %4$s" : "%1$s, %2$s, %3$s e %4$s",
    "%1$s, %2$s, %3$s, %4$s and %5$s" : "%1$s, %2$s, %3$s, %4$s e %5$s",
    "Education Edition" : "Edição Educativa",
    "Enterprise bundle" : "Pacote Enterprise",
    "Groupware bundle" : "Pacote Groupware",
    "Hub bundle" : "Pacote de hub",
    "Social sharing bundle" : "Pacote de compartilhamento social",
    "PHP %s or higher is required." : "PHP %s ou superior é necessário.",
    "PHP with a version lower than %s is required." : "É necessária uma versão PHP mais antiga que a %s.",
    "%sbit or higher PHP required." : "%sbit ou PHP maior é requerido.",
    "The following architectures are supported: %s" : "As seguintes plataformas são suportadas: %s",
    "The following databases are supported: %s" : "Os seguintes bancos de dados são suportados: %s",
    "The command line tool %s could not be found" : "A ferramenta de linha de comando %s não pôde ser encontrada",
    "The library %s is not available." : "A biblioteca %s não está disponível.",
    "Library %1$s with a version higher than %2$s is required - available version %3$s." : "Uma biblioteca %1$s com uma versão maior que %2$s é requerida - versão disponível %3$s.",
    "Library %1$s with a version lower than %2$s is required - available version %3$s." : "Uma biblioteca %1$s com uma versão abaixo de%2$s é requerida - versão disponível %3$s.",
    "The following platforms are supported: %s" : "As seguintes plataformas são suportadas: %s",
    "Server version %s or higher is required." : "É requerido um servidor da versão %s ou superior.",
    "Server version %s or lower is required." : "É requerido um servidor da versão %s ou abaixo.",
    "Logged in user must be an admin, a sub admin or gotten special right to access this setting" : "O usuário conectado deve ser um administrador, um subadministrador ou ter direito especial para acessar esta configuração",
    "Logged in user must be an admin or sub admin" : "O usuário conectado deve ser um administrador ou subadministrador",
    "Logged in user must be an admin" : "O usuário conectado deve ser um administrador",
    "Wiping of device %s has started" : "Limpeza do dispositivo %s iniciou",
    "Wiping of device »%s« has started" : "A limpeza do dispositivo »%s« terminou",
    "»%s« started remote wipe" : "»%s« iniciou a limpeza remota",
    "Device or application »%s« has started the remote wipe process. You will receive another email once the process has finished" : "O dispositivo ou aplicativo »%s« iniciou o processo de limpeza remota. Você receberá outro e-mail assim que terminar",
    "Wiping of device %s has finished" : "Limpeza do dispositivo %s terminou",
    "Wiping of device »%s« has finished" : "Limpeza do dispositivo »%s« terminou",
    "»%s« finished remote wipe" : "»%s« terminou a limpeza remota",
    "Device or application »%s« has finished the remote wipe process." : "O dispositivo ou aplicativo »%s« terminou o processo de limpeza remota.",
    "Remote wipe started" : "Limpeza remota iniciada",
    "A remote wipe was started on device %s" : "Uma limpeza remota iniciou no dispositivo %s",
    "Remote wipe finished" : "Limpeza remota terminada",
    "The remote wipe on %s has finished" : "A limpeza remota em %s terminou",
    "Authentication" : "Autenticação",
    "Unknown filetype" : "Tipo de arquivo desconhecido",
    "Invalid image" : "Imagem inválida",
    "Avatar image is not square" : "A imagem do avatar não é quadrada",
    "View profile" : "Visualizar perfil",
    "Local time: %s" : "Hora local: %s",
    "today" : "hoje",
    "tomorrow" : "amanhã",
    "yesterday" : "ontem",
    "_in %n day_::_in %n days_" : ["em %n dia","em %n dias","em %n dias"],
    "_%n day ago_::_%n days ago_" : ["%n dia atrás","%n dias atrás","%n dias atrás"],
    "next month" : "Mês que vem",
    "last month" : "último mês",
    "_in %n month_::_in %n months_" : ["em %n mês","em %n meses","em %n meses"],
    "_%n month ago_::_%n months ago_" : ["há %n mês atrás","há %n meses","há %n meses"],
    "next year" : "ano que vem",
    "last year" : "último ano",
    "_in %n year_::_in %n years_" : ["em %n ano","em %n anos","em %n anos"],
    "_%n year ago_::_%n years ago_" : ["%n ano atrás","%n anos atrás","%n anos atrás"],
    "_in %n hour_::_in %n hours_" : ["em %n hora","em %n horas","em %n horas"],
    "_%n hour ago_::_%n hours ago_" : ["há %n hora atrás","há %n horas","há %n horas"],
    "_in %n minute_::_in %n minutes_" : ["em %n minuto","em %n minutos","em %n minutos"],
    "_%n minute ago_::_%n minutes ago_" : ["há %n minuto atrás","há %n minutos","há %n minutos"],
    "in a few seconds" : "Em alguns segundos",
    "seconds ago" : "segundos atrás",
    "Empty file" : "Arquivo vazio",
    "Module with ID: %s does not exist. Please enable it in your apps settings or contact your administrator." : "O módulo com a ID: %s não existe. Por favor, habilite-o nas configurações de seu aplicativo ou contacte o administrador.",
    "File already exists" : "O arquivo já existe",
    "Invalid path" : "Diretório inválido",
    "Failed to create file from template" : "Falha ao criar arquivo do modelo ",
    "Templates" : "Modelos ",
    "File name is a reserved word" : "O nome do arquivo é uma palavra reservada",
    "File name contains at least one invalid character" : "O nome do arquivo contém pelo menos um caracter inválido",
    "File name is too long" : "O nome do arquivo é muito longo",
    "Dot files are not allowed" : "Arquivos Dot não são permitidos",
    "Empty filename is not allowed" : "Nome vazio para arquivo não é permitido.",
    "App \"%s\" cannot be installed because appinfo file cannot be read." : "O aplicativo \"%s\" não pode ser instalado pois o arquivo appinfo não pôde ser lido.",
    "App \"%s\" cannot be installed because it is not compatible with this version of the server." : "O aplicativo \"%s\" não pode ser instalado pois não é compatível com a versão do servidor.",
    "__language_name__" : "Português Brasileiro",
    "This is an automatically sent email, please do not reply." : "Este e-mail é enviado automaticamente. Por favor, não responda.",
    "Help" : "Ajuda",
    "Appearance and accessibility" : "Aparência e acessibilidade",
    "Apps" : "Aplicativos",
    "Personal settings" : "Configurações pessoais",
    "Administration settings" : "Configurações de administração",
    "Settings" : "Configurações",
    "Log out" : "Sair",
    "Users" : "Usuários",
    "Email" : "E-mail",
    "Mail %s" : "E-Mail %s",
    "Fediverse" : "Fediverse",
    "View %s on the fediverse" : "Ver %s no fediverse",
    "Phone" : "Fone",
    "Call %s" : "Chamar %s",
    "Twitter" : "Twitter",
    "View %s on Twitter" : "Visualizar %s no Twitter",
    "Website" : "Website",
    "Visit %s" : "Visitar %s",
    "Address" : "Endereço",
    "Profile picture" : "Foto do perfil",
    "About" : "Sobre",
    "Full name" : "Nome completo ",
    "Headline" : "Título ",
    "Organisation" : "Organização",
    "Role" : "Função",
    "Unknown user" : "Usuário desconhecido",
    "Additional settings" : "Configurações adicionais",
    "Enter the database username and name for %s" : "Digite o nome de usuário e o nome do banco de dados para %s",
    "Enter the database username for %s" : "Digite o nome de usuário do banco de dados para %s",
    "Enter the database name for %s" : "Digite o nome do banco de dados para %s",
    "You cannot use dots in the database name %s" : "Você não pode usar pontos no nome do banco de dados %s",
    "MySQL username and/or password not valid" : "Nome de usuário e/ou senha do MySQL inválidos",
    "You need to enter details of an existing account." : "Você necessita entrar detalhes de uma conta existente.",
    "Oracle connection could not be established" : "Conexão Oracle não pôde ser estabelecida",
    "Oracle username and/or password not valid" : "Nome de usuário e/ou senha Oracle inválidos",
    "PostgreSQL username and/or password not valid" : "Nome de usuário e/ou senha PostgreSQL inválidos",
    "Mac OS X is not supported and %s will not work properly on this platform. Use it at your own risk! " : "Mac OS X não é suportado e %s não funcionará corretamente nesta plataforma. Use-o por sua conta e risco!",
    "For the best results, please consider using a GNU/Linux server instead." : "Para obter melhores resultados, por favor considere o uso de um servidor GNU/Linux em seu lugar.",
    "It seems that this %s instance is running on a 32-bit PHP environment and the open_basedir has been configured in php.ini. This will lead to problems with files over 4 GB and is highly discouraged." : "Aparentemente a instância %s está rodando em um ambiente PHP de 32 bits e o open_basedir foi configurado no php.ini. Isto pode gerar problemas com arquivos maiores que 4GB e é altamente não recomendável.",
    "Please remove the open_basedir setting within your php.ini or switch to 64-bit PHP." : "Por favor, remova a configuração de open_basedir de seu php.ini ou mude o PHP para 64bit.",
    "Set an admin username." : "Defina um nome do usuário administrador.",
    "Set an admin password." : "Defina uma senha para o administrador.",
    "Cannot create or write into the data directory %s" : "Não foi possível criar ou escrever no diretório de dados %s",
    "Sharing backend %s must implement the interface OCP\\Share_Backend" : "A plataforma de compartilhamento %s deve implementar a interface OCP\\Share_Backend",
    "Sharing backend %s not found" : "Plataforma de serviço de compartilhamento %s não encontrada",
    "Sharing backend for %s not found" : "Plataforma  de compartilhamento para %s não foi encontrada",
    "%1$s shared »%2$s« with you and wants to add:" : "%1$s compartilhou »%2$s« com você e quer adicionar:",
    "%1$s shared »%2$s« with you and wants to add" : "%1$s compartilhou »%2$s« com você e quer adicionar",
    "»%s« added a note to a file shared with you" : "»%s« adicionou uma anotação num arquivo compartilhado com você",
    "Open »%s«" : "Abrir »%s«",
    "%1$s via %2$s" : "%1$s via %2$s",
    "You are not allowed to share %s" : "Você não tem permissão para compartilhar %s",
    "Cannot increase permissions of %s" : "Não foi possível aumentar as permissões de %s",
    "Files cannot be shared with delete permissions" : "Arquivos não podem ser compartilhados com permissões de exclusão",
    "Files cannot be shared with create permissions" : "Arquivos não podem ser compartilhados com permissões de criação",
    "Expiration date is in the past" : "Data de expiração está no passado",
    "_Cannot set expiration date more than %n day in the future_::_Cannot set expiration date more than %n days in the future_" : ["Não foi possível definir a data de expiração superior que %n dias no futuro","Não foi possível definir a data de expiração superior que %n dias no futuro","Não foi possível definir a data de expiração superior que %n dias no futuro"],
    "Sharing is only allowed with group members" : "O compartilhamento só é permitido com membros do grupo ",
    "Sharing %s failed, because this item is already shared with user %s" : "Compartilhamento %s falhou, porque este item já está compartilhado com o usuário %s",
    "%1$s shared »%2$s« with you" : "%1$s compartilhou »%2$s« com você",
    "%1$s shared »%2$s« with you." : "%1$s compartilhou »%2$s« com você.",
    "Click the button below to open it." : "Clique no botão abaixo para abri-lo.",
    "The requested share does not exist anymore" : "O compartilhamento solicitado não existe mais",
    "The user was not created because the user limit has been reached. Check your notifications to learn more." : "O usuário não foi criado porque o limite de usuários foi atingido. Confira suas notificações para saber mais.",
    "Could not find category \"%s\"" : "Impossível localizar a categoria \"%s\"",
    "Sunday" : "Domingo",
    "Monday" : "Segunda-feira",
    "Tuesday" : "Terça-feira",
    "Wednesday" : "Quarta-feira",
    "Thursday" : "Quinta-feira",
    "Friday" : "Sexta-feira",
    "Saturday" : "Sábado",
    "Sun." : "Dom.",
    "Mon." : "Seg.",
    "Tue." : "Ter.",
    "Wed." : "Qua.",
    "Thu." : "Qui.",
    "Fri." : "Sex.",
    "Sat." : "Sab.",
    "Su" : "Su",
    "Mo" : "Se",
    "Tu" : "Te",
    "We" : "Qu",
    "Th" : "Qu",
    "Fr" : "Se",
    "Sa" : "Sa",
    "January" : "Janeiro",
    "February" : "Fevereiro",
    "March" : "Março",
    "April" : "Abril",
    "May" : "Maio",
    "June" : "Junho",
    "July" : "Julho",
    "August" : "Agosto",
    "September" : "Setembro",
    "October" : "Outubro",
    "November" : "Novembro",
    "December" : "Dezembro",
    "Jan." : "Jan.",
    "Feb." : "Fev.",
    "Mar." : "Mar.",
    "Apr." : "Abr.",
    "May." : "Mai.",
    "Jun." : "Jun.",
    "Jul." : "Jul.",
    "Aug." : "Ago.",
    "Sep." : "Set.",
    "Oct." : "Out.",
    "Nov." : "Nov.",
    "Dec." : "Dez.",
    "A valid password must be provided" : "Uma senha válida deve ser fornecida",
    "The username is already being used" : "Este nome de usuário já está em uso",
    "Could not create user" : "Não foi possível criar o usuário",
    "Only the following characters are allowed in a username: \"a-z\", \"A-Z\", \"0-9\", spaces and \"_.@-'\"" : "Apenas os seguintes caracteres são permitidos em um nome de usuário: \"a-z\", \"A-Z\", \"0-9\", espaços e \"_.@-'\"",
    "A valid username must be provided" : "Um nome de usuário válido deve ser fornecido",
    "Username contains whitespace at the beginning or at the end" : "O nome de usuário contém espaço em branco no início ou no fim",
    "Username must not consist of dots only" : "Nome do usuário não pode consistir de pontos somente",
    "Username is invalid because files already exist for this user" : "O nome de usuário é inválido porque já exstem arquivos para este usuário",
    "User disabled" : "Usuário desativado",
    "Login canceled by app" : "Login cancelado pelo aplicativo",
    "App \"%1$s\" cannot be installed because the following dependencies are not fulfilled: %2$s" : "O aplicativo \"%1$s\" não pode ser instalado devido à estas dependências: %2$s",
    "a safe home for all your data" : "Um lar seguro para todos os seus dados",
    "File is currently busy, please try again later" : "O arquivo está ocupado, tente novamente mais tarde",
    "Cannot download file" : "Não é possível baixar o arquivo",
    "Application is not enabled" : "O aplicativo não está habilitado",
    "Authentication error" : "Erro de autenticação",
    "Token expired. Please reload page." : "O token expirou. Por favor recarregue a página.",
    "No database drivers (sqlite, mysql, or postgresql) installed." : "Nenhum driver  de banco de dados (sqlite, mysql ou postgresql) instalado.",
    "Cannot write into \"config\" directory." : "Não é possível gravar no diretório \"config\".",
    "This can usually be fixed by giving the web server write access to the config directory. See %s" : "Isso geralmente pode ser corrigido dando ao servidor web acesso de gravação ao diretório de configuração. Ver %s",
    "Or, if you prefer to keep config.php file read only, set the option \"config_is_read_only\" to true in it. See %s" : "Ou, se você preferir manter o arquivo config.php somente para leitura, defina a opção \"config_is_read_only\" como true. Veja %s",
    "Cannot write into \"apps\" directory." : "Não é possível gravar no diretório \"apps\".",
    "This can usually be fixed by giving the web server write access to the apps directory or disabling the App Store in the config file." : "Isso geralmente pode ser corrigido dando ao servidor web acesso de gravação ao diretório de aplicativos ou desabilitando a App Store no arquivo de configuração.",
    "Cannot create \"data\" directory." : "Não é possível criar o diretório \"dados\".",
    "This can usually be fixed by giving the web server write access to the root directory. See %s" : "Isso geralmente pode ser corrigido dando ao servidor web acesso de gravação ao diretório raiz. Ver %s",
    "Permissions can usually be fixed by giving the web server write access to the root directory. See %s." : "As permissões geralmente podem ser corrigidas dando ao servidor web acesso de gravação ao diretório raiz. Ver %s.",
    "Your data directory is not writable." : "Seu diretório de dados não é gravável.",
    "Setting locale to %s failed." : "Falha ao definir a localidade para %s .",
    "Please install one of these locales on your system and restart your web server." : "Instale um dessas localidades em seu sistema e reinicie seu servidor web.",
    "PHP module %s not installed." : "Módulo PHP %s não instalado.",
    "Please ask your server administrator to install the module." : "Por favor, peça ao seu administrador do servidor para instalar o módulo.",
    "PHP setting \"%s\" is not set to \"%s\"." : "Configuração PHP \"%s\" não está configurado para \"%s\".",
    "Adjusting this setting in php.ini will make Nextcloud run again" : "Ajustar a configuração no php.ini fará com que o Nextcloud execute novamente",
    "<code>mbstring.func_overload</code> is set to <code>%s</code> instead of the expected value <code>0</code>." : "<code>mbstring.func_overload</code> está configurado para <code>%s</code> em vez do valor esperado <code>0</code>.",
    "To fix this issue set <code>mbstring.func_overload</code> to <code>0</code> in your php.ini." : "Para corrigir este conjunto de problemas <code>mbstring.func_overload</code> para <code>0</code> no seu php.ini.",
    "libxml2 2.7.0 is at least required. Currently %s is installed." : "A libxml2 2.7.0 é a versão mínima necessária. Atualmente a versão %s está instalada.",
    "To fix this issue update your libxml2 version and restart your web server." : "Para corrigir este problema, atualize a versão da sua libxml2 e reinicie seu servidor web.",
    "PHP is apparently set up to strip inline doc blocks. This will make several core apps inaccessible." : "PHP aparentemente está configurado para retirar blocos doc inline. Isso fará com que vários aplicativos do núcleo fiquem inacessíveis.",
    "This is probably caused by a cache/accelerator such as Zend OPcache or eAccelerator." : "Isso provavelmente é causado por um cache/acelerador, como Zend OPcache ou eAccelerator.",
    "PHP modules have been installed, but they are still listed as missing?" : "Módulos do PHP foram instalados, mas eles ainda estão listados como faltantes?",
    "Please ask your server administrator to restart the web server." : "Por favor peça ao administrador do servidor para reiniciar o servidor web.",
    "The required %s config variable is not configured in the config.php file." : "A variável %s de configuração necessária não está configurada no arquivo config.php.",
    "Please ask your server administrator to check the Nextcloud configuration." : "Peça ao administrador do servidor para verificar a configuração do Nextcloud.",
    "PostgreSQL >= 9 required." : "PostgreSQL >= 9 é necessário.",
    "Please upgrade your database version." : "Por favor, atualize a versão do seu banco de dados.",
    "Your data directory is readable by other users." : "Seu diretório de dados pode ser lido por outros usuários.",
    "Please change the permissions to 0770 so that the directory cannot be listed by other users." : "Por favor altere as permissões para 0770 para que o diretório não possa ser lido por outros usuários.",
    "Your data directory must be an absolute path." : "Seu diretório de dados deve ser um caminho absoluto.",
    "Check the value of \"datadirectory\" in your configuration." : "Verifique o valor de \"datadirectory\" em sua configuração.",
    "Your data directory is invalid." : "Seu diretório de dados é inválido.",
    "Ensure there is a file called \".ocdata\" in the root of the data directory." : "Assegure-se que exista um arquivo chamado \".ocdata\" na raiz do diretório \"data\".",
    "Action \"%s\" not supported or implemented." : "Ação \"%s\" não suportada ou implementada.",
    "Authentication failed, wrong token or provider ID given" : "Falha na autenticação, token ou ID do provedor errados",
    "Parameters missing in order to complete the request. Missing Parameters: \"%s\"" : "Parâmetros ausentes para concluir a solicitação: \"%s\"",
    "ID \"%1$s\" already used by cloud federation provider \"%2$s\"" : "A ID \"%1$s\" já é usada pelo provedor de nuvem federada \"%2$s\"",
    "Cloud Federation Provider with ID: \"%s\" does not exist." : "Provedor da Federação de Nuvem com ID: \"%s\" não existe.",
    "Could not obtain lock type %d on \"%s\"." : "Não foi possível obter tipo de bloqueio %d em \"%s\".",
    "Storage unauthorized. %s" : "Armazenamento não autorizado. %s",
    "Storage incomplete configuration. %s" : "Configuração incompleta do armazenamento. %s",
    "Storage connection error. %s" : "Erro na conexão de armazenamento. %s",
    "Storage is temporarily not available" : "Armazenamento temporariamente indisponível",
    "Storage connection timeout. %s" : "Atingido o tempo limite de conexão ao armazenamento. %s",
    "%s enter the database username and name." : "%s insira o nome de usuário e o nome do banco de dados.",
    "%s enter the database username." : "%s insira o nome de usuário do banco de dados.",
    "%s enter the database name." : "%s insira o nome do banco de dados.",
    "%s you may not use dots in the database name" : "%s você não pode usar pontos no nome do banco de dados",
    "The user limit has been reached and the user was not created. Check your notifications to learn more." : "O limite de usuários foi atingido e o usuário não foi criado. Verifique suas notificações para saber mais.",
    "Only the following characters are allowed in a username: \"a-z\", \"A-Z\", \"0-9\", and \"_.@-'\"" : "Somente os seguintes caracteres são permitidos em um nome de usuário: \"a-z\", \"A-Z\", \"0-9\", e \"_.@-'\""
},
"nplurals=3; plural=(n == 0 || n == 1) ? 0 : n != 0 && n % 1000000 == 0 ? 1 : 2;");
